package dev.fitko.fitconnect.client.cmd;

import dev.fitko.fitconnect.client.factory.ClientFactory;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.stream.Collectors;

public final class CommandLineRunner {

    private static final String LOGO = "/splash_screen_banner.txt";

    private static final Logger LOGGER = LoggerFactory.getLogger(CommandLineRunner.class);

    private CommandLineRunner() {
    }

    public static void main(final String[] args) throws IOException {
        printSplashScreen();
        run(args);
    }

    private static void printSplashScreen() {
        LOGGER.info("{}", getSplashScreenResource(LOGO));
    }

    private static void run(final String[] args) throws IOException {
        final var senderClient = ClientFactory.senderClient();
        final var subscriberClient = ClientFactory.subscriberClient();
        new CommandLineClient(senderClient, subscriberClient).run(args);
    }

    private static String getSplashScreenResource(final String bannerName) {
        final InputStream is = CommandLineRunner.class.getResourceAsStream(bannerName);
        return new BufferedReader(new InputStreamReader(is)).lines().collect(Collectors.joining("\n"));
    }
}
